/*
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"context"
	"time"

	v1alpha1 "github.com/openservicemesh/osm/pkg/apis/policy/v1alpha1"
	scheme "github.com/openservicemesh/osm/pkg/gen/client/policy/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// RetriesGetter has a method to return a RetryInterface.
// A group's client should implement this interface.
type RetriesGetter interface {
	Retries(namespace string) RetryInterface
}

// RetryInterface has methods to work with Retry resources.
type RetryInterface interface {
	Create(ctx context.Context, retry *v1alpha1.Retry, opts v1.CreateOptions) (*v1alpha1.Retry, error)
	Update(ctx context.Context, retry *v1alpha1.Retry, opts v1.UpdateOptions) (*v1alpha1.Retry, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.Retry, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.RetryList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Retry, err error)
	RetryExpansion
}

// retries implements RetryInterface
type retries struct {
	client rest.Interface
	ns     string
}

// newRetries returns a Retries
func newRetries(c *PolicyV1alpha1Client, namespace string) *retries {
	return &retries{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the retry, and returns the corresponding retry object, and an error if there is any.
func (c *retries) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1alpha1.Retry, err error) {
	result = &v1alpha1.Retry{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("retries").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of Retries that match those selectors.
func (c *retries) List(ctx context.Context, opts v1.ListOptions) (result *v1alpha1.RetryList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.RetryList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("retries").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested retries.
func (c *retries) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("retries").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a retry and creates it.  Returns the server's representation of the retry, and an error, if there is any.
func (c *retries) Create(ctx context.Context, retry *v1alpha1.Retry, opts v1.CreateOptions) (result *v1alpha1.Retry, err error) {
	result = &v1alpha1.Retry{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("retries").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(retry).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a retry and updates it. Returns the server's representation of the retry, and an error, if there is any.
func (c *retries) Update(ctx context.Context, retry *v1alpha1.Retry, opts v1.UpdateOptions) (result *v1alpha1.Retry, err error) {
	result = &v1alpha1.Retry{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("retries").
		Name(retry.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(retry).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the retry and deletes it. Returns an error if one occurs.
func (c *retries) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("retries").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *retries) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("retries").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched retry.
func (c *retries) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Retry, err error) {
	result = &v1alpha1.Retry{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("retries").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
